@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,14 +17,16 @@
  */
 package org.apache.tools.ant.taskdefs.optional.junit;
 
+import static org.hamcrest.Matchers.containsString;
+import static org.hamcrest.Matchers.not;
+import static org.hamcrest.Matchers.startsWith;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertThat;
 import static org.junit.Assert.assertTrue;
-
-import static org.apache.tools.ant.AntAssert.assertNotContains;
-import static org.apache.tools.ant.AntAssert.assertContains;
+import static org.junit.Assume.assumeTrue;
 
 import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
@@ -35,7 +37,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.Arrays;
-import java.util.Collections;
 import java.util.Set;
 import java.util.TreeSet;
 
@@ -44,17 +45,15 @@ import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.xpath.XPath;
 import javax.xml.xpath.XPathConstants;
 import javax.xml.xpath.XPathFactory;
-import org.apache.tools.ant.BuildException;
 
+import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.BuildFileRule;
 import org.apache.tools.ant.MagicNames;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.launcher.CommandLauncher;
-import org.apache.tools.ant.taskdefs.optional.junit.JUnitTask.ForkMode;
 import org.apache.tools.ant.types.Path;
 import org.apache.tools.ant.util.JavaEnvUtils;
 import org.apache.tools.ant.util.LoaderUtils;
-import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -63,43 +62,43 @@ import org.w3c.dom.Node;
 
 public class JUnitTaskTest {
 
-	@Rule
-	public BuildFileRule buildRule = new BuildFileRule();
-	
+    @Rule
+    public BuildFileRule buildRule = new BuildFileRule();
+
     /**
      * The JUnit setup method.
      */
-	@Before
+    @Before
     public void setUp() {
         buildRule.configureProject("src/etc/testcases/taskdefs/optional/junit.xml");
     }
 
-	@Test
+    @Test
     public void testCrash() {
-    	buildRule.executeTarget("crash");
-    	assertEquals("true", buildRule.getProject().getProperty("crashed"));
+        buildRule.executeTarget("crash");
+        assertEquals("true", buildRule.getProject().getProperty("crashed"));
     }
 
-	@Test
+    @Test
     public void testNoCrash() {
-    	buildRule.executeTarget("nocrash");
-    	assertNull(buildRule.getProject().getProperty("crashed"));
+        buildRule.executeTarget("nocrash");
+        assertNull(buildRule.getProject().getProperty("crashed"));
     }
 
-	@Test
+    @Test
     public void testTimeout() {
-    	buildRule.executeTarget("timeout");
-    	assertEquals("true", buildRule.getProject().getProperty("timeout"));
+        buildRule.executeTarget("timeout");
+        assertEquals("true", buildRule.getProject().getProperty("timeout"));
     }
 
     @Test
     public void testNoTimeout() {
        buildRule.executeTarget("notimeout");
-   	   assertNull(buildRule.getProject().getProperty("timeout"));
+       assertNull(buildRule.getProject().getProperty("timeout"));
     }
 
     @Test
-    public void testNonForkedCapture() throws IOException {
+    public void testNonForkedCapture() {
         buildRule.executeTarget("capture");
         assertNoPrint(buildRule.getLog(), "log");
         assertNoPrint(buildRule.getFullLog(), "debug log");
@@ -141,8 +140,8 @@ public class JUnitTaskTest {
     public void testFailureRecorder() {
         if (JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_1_5)) {
             try {
-            	Class<?> clazz =Class.forName("junit.framework.JUnit4TestAdapter");
-                Assume.assumeFalse("Skipping test since it fails with JUnit 4", clazz != null);
+                Class<?> clazz = Class.forName("junit.framework.JUnit4TestAdapter");
+                assumeTrue("Skipping test since it fails with JUnit 4", clazz == null);
             } catch (ClassNotFoundException e) {
                 // OK, this is JUnit3, can run test
             }
@@ -154,14 +153,14 @@ public class JUnitTaskTest {
 
         // ensure that there is a clean test environment
         assertFalse("Test directory '" + testDir.getAbsolutePath()
-                    + "' must not exist before the test preparation.", 
+                    + "' must not exist before the test preparation.",
                     testDir.exists());
         assertFalse("The collector file '"
                     + collectorFile.getAbsolutePath()
-                    + "'must not exist before the test preparation.", 
+                    + "'must not exist before the test preparation.",
                     collectorFile.exists());
 
-    
+
         // prepare the test environment
         buildRule.executeTarget("failureRecorder.prepare");
         assertTrue("Test directory '" + testDir.getAbsolutePath()
@@ -169,99 +168,101 @@ public class JUnitTaskTest {
         assertTrue("There should be one class.",
                    (new File(testDir, "A.class")).exists());
         assertFalse("The collector file '"
-                    + collectorFile.getAbsolutePath() 
+                    + collectorFile.getAbsolutePath()
                     + "' should not exist before the 1st run.",
                     collectorFile.exists());
-    
-    
+
+
         // 1st junit run: should do all tests - failing and not failing tests
         buildRule.executeTarget("failureRecorder.runtest");
-        assertTrue("The collector file '" + collectorFile.getAbsolutePath() 
+        assertTrue("The collector file '" + collectorFile.getAbsolutePath()
                    + "' should exist after the 1st run.",
                    collectorFile.exists());
         // the passing test cases
         buildRule.executeTarget("A.test01");
-        assertContains("1st run: should run A.test01", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run A.test01"));
         buildRule.executeTarget("B.test05");
-        assertContains("1st run: should run B.test05", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run B.test05"));
         buildRule.executeTarget("B.test06");
-        assertContains("1st run: should run B.test06", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run B.test06"));
         buildRule.executeTarget("C.test07");
-        assertContains("1st run: should run C.test07", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run C.test07"));
         buildRule.executeTarget("C.test08");
-        assertContains("1st run: should run C.test08", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run C.test08"));
         buildRule.executeTarget("C.test09");
-        assertContains("1st run: should run C.test09", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run C.test09"));
         // the failing test cases
         buildRule.executeTarget("A.test02");
-        assertContains("1st run: should run A.test02", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run A.test02"));
         buildRule.executeTarget("A.test03");
-        assertContains("1st run: should run A.test03", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run A.test03"));
         buildRule.executeTarget("B.test04");
-        assertContains("1st run: should run B.test04", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run B.test04"));
         buildRule.executeTarget("D.test10");
-        assertContains("1st run: should run D.test10", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("1st run: should run D.test10"));
+
 
-    
         // 2nd junit run: should do only failing tests
         buildRule.executeTarget("failureRecorder.runtest");
-        assertTrue("The collector file '" + collectorFile.getAbsolutePath() 
+        assertTrue("The collector file '" + collectorFile.getAbsolutePath()
                    + "' should exist after the 2nd run.",
                    collectorFile.exists());
         // the passing test cases
         buildRule.executeTarget("A.test01");
-        assertNotContains("2nd run: should not run A.test01", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run A.test01")));
         buildRule.executeTarget("B.test05");
-        assertNotContains("2nd run: should not run A.test05", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run A.test05")));
         buildRule.executeTarget("B.test06");
-        assertNotContains("2nd run: should not run B.test06", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run B.test06")));
         buildRule.executeTarget("C.test07");
-        assertNotContains("2nd run: should not run C.test07", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run C.test07")));
         buildRule.executeTarget("C.test08");
-        assertNotContains("2nd run: should not run C.test08", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run C.test08")));
         buildRule.executeTarget("C.test09");
-        assertNotContains("2nd run: should not run C.test09", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), not(containsString("2nd run: should not run C.test09")));
         // the failing test cases
         buildRule.executeTarget("A.test02");
-        assertContains("2nd run: should run A.test02", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("2nd run: should run A.test02"));
         buildRule.executeTarget("A.test03");
-        assertContains("2nd run: should run A.test03", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("2nd run: should run A.test03"));
         buildRule.executeTarget("B.test04");
-        assertContains("2nd run: should run B.test04", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("2nd run: should run B.test04"));
         buildRule.executeTarget("D.test10");
-        assertContains("2nd run: should run D.test10", buildRule.getOutput());
-    
-    
+        assertThat(buildRule.getOutput(), containsString("2nd run: should run D.test10"));
+
+
         // "fix" errors in class A
         buildRule.executeTarget("failureRecorder.fixing");
-    
+
         // 3rd run: four running tests with two errors
         buildRule.executeTarget("failureRecorder.runtest");
-        assertTrue("The collector file '" + collectorFile.getAbsolutePath() 
+        assertTrue("The collector file '" + collectorFile.getAbsolutePath()
                    + "' should exist after the 3rd run.",
                    collectorFile.exists());
         buildRule.executeTarget("A.test02");
-        assertContains("3rd run: should run A.test02", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("3rd run: should run A.test02"));
         buildRule.executeTarget("A.test03");
-        assertContains("3rd run: should run A.test03", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("3rd run: should run A.test03"));
         buildRule.executeTarget("B.test04");
-        assertContains("3rd run: should run B.test04", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("3rd run: should run B.test04"));
         buildRule.executeTarget("D.test10");
-        assertContains("3rd run: should run D.test10", buildRule.getOutput());
-    
-    
+        assertThat(buildRule.getOutput(), containsString("3rd run: should run D.test10"));
+
+
         // 4rd run: two running tests with errors
         buildRule.executeTarget("failureRecorder.runtest");
-        assertTrue("The collector file '" + collectorFile.getAbsolutePath() 
+        assertTrue("The collector file '" + collectorFile.getAbsolutePath()
                    + "' should exist after the 4th run.",
                    collectorFile.exists());
-        //TODO: these two statements fail
-        //buildRule.executeTarget("A.test02");assertNotContains("4th run: should not run A.test02", buildRule.getOutput());
-        //buildRule.executeTarget("A.test03");assertNotContains("4th run: should not run A.test03", buildRule.getOutput());
+        //TODO: these statements fail
+        //buildRule.executeTarget("A.test02");
+        //assertThat(buildRule.getOutput(), not(containsString("4th run: should not run A.test02")));
+        //buildRule.executeTarget("A.test03");
+        //assertThat(buildRule.getOutput(), not(containsString("4th run: should not run A.test03")));
         buildRule.executeTarget("B.test04");
-        assertContains("4th run: should run B.test04", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("4th run: should run B.test04"));
         buildRule.executeTarget("D.test10");
-        assertContains("4th run: should run D.test10", buildRule.getOutput());
+        assertThat(buildRule.getOutput(), containsString("4th run: should run D.test10"));
 
     }
 
@@ -274,16 +275,16 @@ public class JUnitTaskTest {
     @Test
     public void testMultilineAssertsNoFork() {
         buildRule.executeTarget("testMultilineAssertsNoFork");
-        assertNotContains("messaged up", buildRule.getLog());
-        assertNotContains("crashed)", buildRule.getLog());
+        assertThat(buildRule.getLog(), not(containsString("messaged up")));
+        assertThat(buildRule.getLog(), not(containsString("crashed)")));
     }
 
     // Bugzilla Issue 45411
     @Test
     public void testMultilineAssertsFork() {
         buildRule.executeTarget("testMultilineAssertsFork");
-        assertNotContains("messaged up", buildRule.getLog());
-        assertNotContains("crashed)", buildRule.getLog());
+        assertThat(buildRule.getLog(), not(containsString("messaged up")));
+        assertThat(buildRule.getLog(), not(containsString("crashed)")));
     }
 
     private void assertResultFilesExist(String target, String extension) {
@@ -303,46 +304,37 @@ public class JUnitTaskTest {
     }
 
     private void assertNoPrint(String result, String where) {
-        assertNotContains(where + " '" + result + "' must not contain print statement",
-                   "print to System.", result);
+        assertThat(where + " '" + result + "' must not contain print statement",
+                result, not(containsString("print to System.")));
     }
 
     private void assertOutput() throws IOException {
-        FileReader inner = new FileReader(new File(buildRule.getOutputDir(),
-                                          "testlog.txt"));
-        BufferedReader reader = new BufferedReader(inner);
-        try {
+        FileReader inner = new FileReader(new File(buildRule.getOutputDir(), "testlog.txt"));
+        try (BufferedReader reader = new BufferedReader(inner)) {
             String line = reader.readLine();
-            assertEquals("Testsuite: org.apache.tools.ant.taskdefs.optional.junit.Printer",
-                         line);
+            assertEquals("Testsuite: org.apache.tools.ant.taskdefs.optional.junit.Printer", line);
             line = reader.readLine();
             assertNotNull(line);
-            assertTrue(line.startsWith("Tests run: 1, Failures: 0, Errors: 0, Skipped: 0, Time elapsed:"));
+            assertThat(line, startsWith("Tests run: 1, Failures: 0, Errors: 0, Skipped: 0, Time elapsed:"));
             line = reader.readLine();
-            assertEquals("------------- Standard Output ---------------",
-                         line);
+            assertEquals("------------- Standard Output ---------------", line);
             assertPrint(reader.readLine(), "static", "out");
             assertPrint(reader.readLine(), "constructor", "out");
             assertPrint(reader.readLine(), "method", "out");
             line = reader.readLine();
-            assertEquals("------------- ---------------- ---------------",
-                         line);
+            assertEquals("------------- ---------------- ---------------", line);
             line = reader.readLine();
-            assertEquals("------------- Standard Error -----------------",
-                         line);
+            assertEquals("------------- Standard Error -----------------", line);
             assertPrint(reader.readLine(), "static", "err");
             assertPrint(reader.readLine(), "constructor", "err");
             assertPrint(reader.readLine(), "method", "err");
             line = reader.readLine();
-            assertEquals("------------- ---------------- ---------------",
-                         line);
+            assertEquals("------------- ---------------- ---------------", line);
             line = reader.readLine();
             assertEquals("", line);
             line = reader.readLine();
             assertNotNull(line);
-            assertTrue(line.startsWith("Testcase: testNoCrash took "));
-        } finally {
-            inner.close();
+            assertThat(line, startsWith("Testcase: testNoCrash took "));
         }
     }
 
@@ -364,48 +356,75 @@ public class JUnitTaskTest {
         XPathFactory factory = XPathFactory.newInstance();
         XPath xpath = factory.newXPath();
 
-        assertEquals("Incorrect number of skipped tests in header", 4, Integer.parseInt(xpath.compile("//testsuite/@skipped").evaluate(doc)));
-        assertEquals("Incorrect number of error tests in header", 1, Integer.parseInt(xpath.compile("//testsuite/@errors").evaluate(doc)));
-        assertEquals("Incorrect number of failure tests in header", 2, Integer.parseInt(xpath.compile("//testsuite/@failures").evaluate(doc)));
-        assertEquals("Incorrect number of tests in header", 8, Integer.parseInt(xpath.compile("//testsuite/@tests").evaluate(doc)));
+        assertEquals("Incorrect number of skipped tests in header", 4,
+                Integer.parseInt(xpath.compile("//testsuite/@skipped").evaluate(doc)));
+        assertEquals("Incorrect number of error tests in header", 1,
+                Integer.parseInt(xpath.compile("//testsuite/@errors").evaluate(doc)));
+        assertEquals("Incorrect number of failure tests in header", 2,
+                Integer.parseInt(xpath.compile("//testsuite/@failures").evaluate(doc)));
+        assertEquals("Incorrect number of tests in header", 8,
+                Integer.parseInt(xpath.compile("//testsuite/@tests").evaluate(doc)));
 
 
-        assertEquals("Incorrect ignore message on explicit ignored test", "Please don't ignore me!", xpath.compile("//testsuite/testcase[@name='explicitIgnoreTest']/skipped/@message").evaluate(doc));
-        assertEquals("No message should be set on Ignored tests with no Ignore annotation text", 0, ((Node)xpath.compile("//testsuite/testcase[@name='explicitlyIgnoreTestNoMessage']/skipped").evaluate(doc, XPathConstants.NODE)).getAttributes().getLength());
-        assertEquals("Incorrect ignore message on implicit ignored test", "This test will be ignored", xpath.compile("//testsuite/testcase[@name='implicitlyIgnoreTest']/skipped/@message").evaluate(doc));
-        assertNotNull("Implicit ignore test should have an ignore element", xpath.compile("//testsuite/testcase[@name='implicitlyIgnoreTestNoMessage']/skipped").evaluate(doc, XPathConstants.NODE));
+        assertEquals("Incorrect ignore message on explicit ignored test", "Please don't ignore me!",
+                xpath.compile("//testsuite/testcase[@name='explicitIgnoreTest']/skipped/@message").evaluate(doc));
+        assertEquals("No message should be set on Ignored tests with no Ignore annotation text", 0,
+                ((Node) xpath.compile("//testsuite/testcase[@name='explicitlyIgnoreTestNoMessage']/skipped")
+                        .evaluate(doc, XPathConstants.NODE)).getAttributes().getLength());
+        assertEquals("Incorrect ignore message on implicit ignored test", "This test will be ignored",
+                xpath.compile("//testsuite/testcase[@name='implicitlyIgnoreTest']/skipped/@message").evaluate(doc));
+        assertNotNull("Implicit ignore test should have an ignore element",
+                xpath.compile("//testsuite/testcase[@name='implicitlyIgnoreTestNoMessage']/skipped").evaluate(doc, XPathConstants.NODE));
 
     }
 
     @Test
-    public void testTestMethods() throws Exception {
+    public void testTestMethods() {
         buildRule.executeTarget("testTestMethods");
     }
 
     @Test
-    public void testNonTestsSkipped() throws Exception {
+    public void testNonTestsSkipped() {
 
         buildRule.executeTarget("testNonTests");
-        assertFalse("Test result should not exist as test was skipped - TEST-org.example.junit.NonTestMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.NonTestMissed.xml").exists());
-        assertFalse("Test result should not exist as test was skipped - TEST-org.example.junit.JUnit3NonTestMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.JUnit3TestMissed.xml").exists());
-        assertFalse("Test result should not exist as test was skipped - TEST-org.example.junit.AbstractTestMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractTestMissed.xml").exists());
-        assertFalse("Test result should not exist as test was skipped - TEST-org.example.junit.AbstractJUnit3TestMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractJUnit3TestMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.AbstractTestNotMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractTestNotMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.AbstractJUnit3TestNotMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractJUnit3TestNotMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.TestNotMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.TestNotMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.JUnit3TestNotMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.JUnit3TestNotMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.TestWithSuiteNotMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.TestWithSuiteNotMissed.xml").exists());
+        assertFalse("Test result should not exist as test was skipped - TEST-org.example.junit.NonTestMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.NonTestMissed.xml").exists());
+        assertFalse("Test result should not exist as test was skipped - TEST-org.example.junit.JUnit3NonTestMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.JUnit3TestMissed.xml").exists());
+        assertFalse("Test result should not exist as test was skipped - TEST-org.example.junit.AbstractTestMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractTestMissed.xml").exists());
+        assertFalse("Test result should not exist as test was skipped - TEST-org.example.junit.AbstractJUnit3TestMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractJUnit3TestMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.AbstractTestNotMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractTestNotMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.AbstractJUnit3TestNotMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractJUnit3TestNotMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.TestNotMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.TestNotMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.JUnit3TestNotMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.JUnit3TestNotMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.TestWithSuiteNotMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.TestWithSuiteNotMissed.xml").exists());
 
         buildRule.executeTarget("testNonTestsRun");
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.NonTestMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.NonTestMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.JUnit3NonTestMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.JUnit3NonTestMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.TestNotMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.TestNotMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.JUnit3TestNotMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.JUnit3TestNotMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.AbstractTestMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractTestMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.AbstractTestNotMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractTestNotMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.AbstractJUnit3TestMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractJUnit3TestMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.JUnit3NonTestMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.JUnit3NonTestMissed.xml").exists());
-        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.TestWithSuiteNotMissed.xml", new File(buildRule.getOutputDir(), "TEST-org.example.junit.TestWithSuiteNotMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.NonTestMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.NonTestMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.JUnit3NonTestMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.JUnit3NonTestMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.TestNotMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.TestNotMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.JUnit3TestNotMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.JUnit3TestNotMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.AbstractTestMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractTestMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.AbstractTestNotMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractTestNotMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.AbstractJUnit3TestMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.AbstractJUnit3TestMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.JUnit3NonTestMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.JUnit3NonTestMissed.xml").exists());
+        assertTrue("Test result should exist as test was not skipped - TEST-org.example.junit.TestWithSuiteNotMissed.xml",
+                new File(buildRule.getOutputDir(), "TEST-org.example.junit.TestWithSuiteNotMissed.xml").exists());
 
 
     }
@@ -441,10 +460,10 @@ public class JUnitTaskTest {
         final File tmp = new File(System.getProperty("java.io.tmpdir"));    //NOI18N
         final File workDir = new File(tmp, String.format("%s_testJCP%d",    //NOI18N
                 getClass().getName(),
-                System.currentTimeMillis()/1000));
+                System.currentTimeMillis() / 1000));
         workDir.mkdirs();
         try {
-            final File modulesDir = new File(workDir,"modules");    //NOI18N
+            final File modulesDir = new File(workDir, "modules");    //NOI18N
             modulesDir.mkdirs();
 
             final Project project = new Project();
@@ -473,7 +492,7 @@ public class JUnitTaskTest {
             String resCp = null;
             String resMp = null;
             Set<String> resExports = new TreeSet<>();
-            for (int i = 1; i< mockProcLauncher.cmd.length; i++) {
+            for (int i = 1; i < mockProcLauncher.cmd.length; i++) {
                 if ("-classpath".equals(mockProcLauncher.cmd[i])) { //NOI18N
                     resCp = mockProcLauncher.cmd[++i];
                 } else if ("--module-path".equals(mockProcLauncher.cmd[i])) { //NOI18N
@@ -486,7 +505,8 @@ public class JUnitTaskTest {
             }
             assertTrue("No exports", resExports.isEmpty());
             if (project.getProperty(MagicNames.BUILD_SYSCLASSPATH) == null
-                && System.getProperty(MagicNames.BUILD_SYSCLASSPATH) == null) {
+                && System.getProperty(MagicNames.BUILD_SYSCLASSPATH) == null
+                && project.getProperty("tests.and.ant.share.classloader") == null) {
                 assertEquals("Expected classpath", cp.toString(), resCp);
             }
             assertEquals("Expected modulepath", mp.toString(), resMp);
@@ -500,10 +520,10 @@ public class JUnitTaskTest {
         final File tmp = new File(System.getProperty("java.io.tmpdir"));    //NOI18N
         final File workDir = new File(tmp, String.format("%s_testJMP%d",    //NOI18N
                 getClass().getName(),
-                System.currentTimeMillis()/1000));
+                System.currentTimeMillis() / 1000));
         workDir.mkdirs();
         try {
-            final File modulesDir = new File(workDir,"modules");    //NOI18N
+            final File modulesDir = new File(workDir, "modules");    //NOI18N
             modulesDir.mkdirs();
 
             final Project project = new Project();
@@ -530,7 +550,7 @@ public class JUnitTaskTest {
             String resCp = null;
             String resMp = null;
             Set<String> resExports = new TreeSet<>();
-            for (int i = 1; i< mockProcLauncher.cmd.length; i++) {
+            for (int i = 1; i < mockProcLauncher.cmd.length; i++) {
                 if ("-classpath".equals(mockProcLauncher.cmd[i])) { //NOI18N
                     resCp = mockProcLauncher.cmd[++i];
                 } else if ("--module-path".equals(mockProcLauncher.cmd[i])) { //NOI18N
@@ -543,7 +563,8 @@ public class JUnitTaskTest {
             }
             assertTrue("No exports", resExports.isEmpty());
             if (project.getProperty(MagicNames.BUILD_SYSCLASSPATH) == null
-                && System.getProperty(MagicNames.BUILD_SYSCLASSPATH) == null) {
+                && System.getProperty(MagicNames.BUILD_SYSCLASSPATH) == null
+                && project.getProperty("tests.and.ant.share.classloader") == null) {
                 assertNull("No classpath", resCp);
             }
             assertEquals("Expected modulepath", mp.toString(), resMp);
@@ -552,13 +573,43 @@ public class JUnitTaskTest {
         }
     }
 
+    private void setupCheckDuplicateTest() {
+        final String projectResourceName =
+                LoaderUtils.classNameToResource(Project.class.getName());
+        final File antclasses = LoaderUtils.getResourceSource(
+                Project.class.getClassLoader(), projectResourceName);
+        assumeTrue("skipping test as ant is found inside of a jar rather than a directory",
+                   antclasses.isDirectory());
+        final String testResourceName =
+                LoaderUtils.classNameToResource(junit.framework.Test.class.getName());
+        final File junitJar = LoaderUtils.getResourceSource(
+                Project.class.getClassLoader(), testResourceName);
+        buildRule.getProject().setProperty("antclasses", antclasses.getAbsolutePath());
+        buildRule.getProject().setProperty("junitjar", junitJar.getAbsolutePath());
+    }
+
+    @Test
+    public void testCheckDuplicateAntJar() {
+        setupCheckDuplicateTest();
+        buildRule.executeTarget("testCheckForkedPath");
+        assertThat("Expecting the warning about the duplicate ant jar", buildRule.getLog(),
+                containsString("WARNING: multiple versions of ant detected in path for junit"));
+    }
+
+    @Test
+    public void testCheckNonDuplicateAntJar() {
+        setupCheckDuplicateTest();
+        buildRule.getProject().setProperty("includeantruntime", "no");
+        buildRule.executeTarget("testCheckForkedPath");
+        assertThat("Unexpected warning about the duplicate ant jar", buildRule.getLog(),
+                not(containsString("WARNING: multiple versions of ant detected in path for junit")));
+    }
+
     private void delete(File f) {
         if (f.isDirectory()) {
             final File[] clds = f.listFiles();
             if (clds != null) {
-                for (File cld : clds) {
-                    delete(cld);
-                }
+                Arrays.stream(clds).forEach(this::delete);
             }
         }
         f.delete();
